==> org-lsst-ccs-subsystem-refrig-gui-4.2.5-sources.jar: org/lsst/ccs/subsystem/refrig/ui/ThermalControlPanel.java <==
package org.lsst.ccs.subsystem.refrig.ui;

import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import javax.swing.JPanel;
import javax.swing.SwingUtilities;
import org.lsst.ccs.subsystem.common.ui.SystemStatusPanel;
import org.lsst.ccs.subsystem.common.ui.UiUtilities;
import org.lsst.ccs.subsystem.common.ui.jas.CommandSender;
import org.lsst.ccs.subsystem.refrig.constants.RefrigConstants;
import org.lsst.ccs.subsystem.refrig.data.ThermalState;

/**
 *  Implements the thermal control panel.
 *
 *  @author Owen Saxton
 */
public class ThermalControlPanel extends JPanel implements CommandSender.ReplyHandler, UiUtilities.ActionHandler {

    private final CommandSender sender;
    private SystemStatusPanel statusPanel;
    private final TrimHeaterPanel[] trimHeaterPanels = new TrimHeaterPanel[ThermalState.NUM_TRIM_HEATERS];
    private JPanel trimPanel;
    private final JPanel mainPanel = new JPanel();
    private Integer[] trimHeaters = new Integer[0];

    public ThermalControlPanel(String agent) {
        sender = new CommandSender(agent, this);
        initComponents();
        (new DisablePanel()).run();
    }

    public void initPanel() {
        sender.sendCommand(true, null, "getSystemState");
    }

    @Override
    public void onCommandReply(Object reply, String path, String command, Object[] args) {
        updatePanel((ThermalState)reply);
    }

    public void updatePanel(ThermalState rs) {
        SwingUtilities.invokeLater(new UpdateThermalState(rs));
    }

    public void disablePanel() {
        SwingUtilities.invokeLater(new DisablePanel());
    }

    private void initComponents() {

        // Create status line panel
        statusPanel = new SystemStatusPanel(sender, RefrigConstants.MONITOR_CONTROL);

        // Create trim heater line panels
        for (int htr = 0; htr < ThermalState.NUM_TRIM_HEATERS; htr++) {
            trimHeaterPanels[htr] = new TrimHeaterPanel(htr, sender);
        }

        // Create trim heater control panel
        trimPanel = UiUtilities.newBorderedPanel("Trim heater control");

        // Add panels to main panel
        mainPanel.setLayout(new GridBagLayout());
        GridBagConstraints gbm = new GridBagConstraints();
        gbm.insets = new Insets(5, 0, 0, 0);
        gbm.gridx = 0;
        gbm.gridy = 0;
        gbm.anchor = GridBagConstraints.NORTH;
        mainPanel.add(statusPanel, gbm);
        gbm.gridy++;
        gbm.insets.bottom = 5;
        mainPanel.add(trimPanel, gbm);

        // Lay out the complete panel
        add(mainPanel);
    }

    private void updateTrimPanel(Integer[] newTrimHeaters) {
        for (int htr : trimHeaters) {
            trimPanel.remove(trimHeaterPanels[htr]);
        }
        trimHeaters = newTrimHeaters;
        GridBagConstraints gbt = new GridBagConstraints();
        gbt.insets = new Insets(5, 0, 0, 0);
        gbt.gridx = 0;
        gbt.gridy = 0;
        gbt.anchor = GridBagConstraints.NORTH;
        for (int htr : trimHeaters) {
            gbt.insets.bottom = gbt.gridy == trimHeaters.length - 1 ? 5 : 0;
            trimPanel.add(trimHeaterPanels[htr], gbt);
            gbt.insets.top = 0;
            gbt.gridy++;
        }
    }

    public ThermalControlPanel() {
        this.sender = null;
    }

    class UpdateThermalState implements Runnable {

        private final ThermalState rs;

        UpdateThermalState(ThermalState rs) {
            this.rs = rs;
        }

        @Override
        public void run() {
            statusPanel.updatePanel(rs.getTickMillis());
            if (rs.getTrimHeaters().length != trimHeaters.length) {
                updateTrimPanel(rs.getTrimHeaters());
            }
            for (int htr : trimHeaters) {
                trimHeaterPanels[htr].updatePanel(rs);
            }
            repaint();
        }

    }

    class DisablePanel implements Runnable {

        @Override
        public void run() {
            statusPanel.disablePanel();
            for (int htr : trimHeaters) {
                trimHeaterPanels[htr].disablePanel();
            }
            repaint();
        }
 
    }

    private static final long serialVersionUID = 1L;
}

==> org-lsst-ccs-subsystem-refrig-gui-4.3.3-sources.jar: org/lsst/ccs/subsystem/refrig/ui/ThermalControlPanel.java <==
package org.lsst.ccs.subsystem.refrig.ui;

import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import javax.swing.JPanel;
import javax.swing.SwingUtilities;
import org.lsst.ccs.subsystem.common.ui.SystemStatusPanel;
import org.lsst.ccs.subsystem.common.ui.UiUtilities;
import org.lsst.ccs.subsystem.common.ui.jas.CommandSender;
import org.lsst.ccs.subsystem.refrig.constants.RefrigConstants;
import org.lsst.ccs.subsystem.refrig.data.ThermalState;

/**
 *  Implements the thermal control panel.
 *
 *  @author Owen Saxton
 */
public class ThermalControlPanel extends JPanel implements CommandSender.ReplyHandler, UiUtilities.ActionHandler {

    private final int LABEL_WIDTH = Math.max(TrimHeaterPanel.getLabelWidth(), BulkSupplyPanel.getLabelWidth());
    private final int STATE_WIDTH = Math.max(TrimHeaterPanel.getStateWidth(), BulkSupplyPanel.getStateWidth());
    private final CommandSender sender;
    private SystemStatusPanel statusPanel;
    private BulkSupplyPanel bulkPanel;
    private final TrimHeaterPanel[] trimHeaterPanels = new TrimHeaterPanel[ThermalState.NUM_TRIM_HEATERS];
    private JPanel trimPanel;
    private final JPanel mainPanel = new JPanel();
    private Integer[] trimHeaters = new Integer[0];

    public ThermalControlPanel(String agent) {
        sender = new CommandSender(agent, this);
        initComponents();
        (new DisablePanel()).run();
    }

    public void initPanel() {
        sender.sendCommand(true, null, "getSystemState");
    }

    @Override
    public void onCommandReply(Object reply, String path, String command, Object[] args) {
        updatePanel((ThermalState)reply);
    }

    public void updatePanel(ThermalState rs) {
        SwingUtilities.invokeLater(new UpdateThermalState(rs));
    }

    public void disablePanel() {
        SwingUtilities.invokeLater(new DisablePanel());
    }

    private void initComponents() {

        // Create status line panel
        statusPanel = new SystemStatusPanel(sender, RefrigConstants.MONITOR_CONTROL);

        // Create bulk supply line panel
        bulkPanel = new BulkSupplyPanel(sender, LABEL_WIDTH, STATE_WIDTH);

        // Create trim heater line panels
        for (int htr = 0; htr < ThermalState.NUM_TRIM_HEATERS; htr++) {
            trimHeaterPanels[htr] = new TrimHeaterPanel(htr, sender, LABEL_WIDTH, STATE_WIDTH);
        }

        // Create trim heater control panel
        trimPanel = UiUtilities.newBorderedPanel("Trim heater control");
        GridBagConstraints gbt = new GridBagConstraints();
        gbt.anchor = GridBagConstraints.NORTHWEST;
        gbt.insets = new Insets(5, 0, 2, 0);
        trimPanel.add(bulkPanel, gbt);

        // Add panels to main panel
        mainPanel.setLayout(new GridBagLayout());
        GridBagConstraints gbm = new GridBagConstraints();
        gbm.insets = new Insets(5, 0, 0, 0);
        gbm.gridx = 0;
        gbm.gridy = 0;
        gbm.anchor = GridBagConstraints.NORTH;
        mainPanel.add(statusPanel, gbm);
        gbm.gridy++;
        gbm.insets.bottom = 5;
        mainPanel.add(trimPanel, gbm);

        // Lay out the complete panel
        add(mainPanel);
    }

    private void updateTrimPanel(Integer[] newTrimHeaters) {
        for (int htr : trimHeaters) {
            trimPanel.remove(trimHeaterPanels[htr]);
        }
        trimHeaters = newTrimHeaters;
        GridBagConstraints gbt = new GridBagConstraints();
        gbt.insets = new Insets(0, 0, 0, 0);
        gbt.gridx = 0;
        gbt.gridy = 1;
        gbt.anchor = GridBagConstraints.NORTH;
        for (int htr : trimHeaters) {
            gbt.insets.bottom = gbt.gridy == trimHeaters.length ? 5 : 0;
            trimPanel.add(trimHeaterPanels[htr], gbt);
            gbt.insets.top = 0;
            gbt.gridy++;
        }
    }

    public ThermalControlPanel() {
        this.sender = null;
    }

    class UpdateThermalState implements Runnable {

        private final ThermalState rs;

        UpdateThermalState(ThermalState rs) {
            this.rs = rs;
        }

        @Override
        public void run() {
            statusPanel.updatePanel(rs.getTickMillis());
            bulkPanel.updatePanel(rs.getBulkPowerState());
            if (rs.getTrimHeaters().length != trimHeaters.length) {
                updateTrimPanel(rs.getTrimHeaters());
            }
            for (int htr : trimHeaters) {
                trimHeaterPanels[htr].updatePanel(rs);
            }
            repaint();
        }

    }

    class DisablePanel implements Runnable {

        @Override
        public void run() {
            statusPanel.disablePanel();
            bulkPanel.disablePanel();
            for (int htr : trimHeaters) {
                trimHeaterPanels[htr].disablePanel();
            }
            repaint();
        }
 
    }

    private static final long serialVersionUID = 1L;
}
